@@ -3,8 +3,11 @@
     a central point to the easy_graphql_server API.
 """
 
+import re
+import json
 import inspect
 from collections import defaultdict
+import logging
 
 from graphql import GraphQLSchema, GraphQLField, GraphQLObjectType
 from graphql.type.validate import validate_schema # pylint: disable=no-name-in-module,import-error
@@ -36,9 +39,13 @@ class Schema:
         Schema can be validated using `Schema.check()`.
     """
 
+    _requests_logger = logging.getLogger('easy_graphql_server.requests')
+    _processing_logger = logging.getLogger('easy_graphql_server.processing')
+
     # public methods
 
-    def __init__(self, debug=False, casing=Casing.SNAKE, restrict_models_queried_fields=False, models_max_depth=None, models_limit=-1):
+    def __init__(self, debug=False, casing=Casing.SNAKE, restrict_models_queried_fields=False,
+        models_max_depth=None, models_limit=-1, models_allowed_lookups=None, models_disallowed_lookups=None):
         self.methods = defaultdict(dict)
         self.subclasses = []
         self.dirty = True
@@ -50,6 +57,8 @@ class Schema:
         self.restrict_models_queried_fields = restrict_models_queried_fields
         self.models_max_depth = models_max_depth
         self.models_limit = models_limit
+        self.models_allowed_lookups = models_allowed_lookups
+        self.models_disallowed_lookups = models_disallowed_lookups
         # abstract parent classes
         class Exposed(exposition.Exposed):
             # pylint: disable=too-few-public-methods,missing-class-docstring
@@ -112,10 +121,9 @@ class Schema:
         self.dirty = True
         if 'restrict_queried_fields' not in options:
             options['restrict_queried_fields'] = self.restrict_models_queried_fields
-        if 'max_depth' not in options:
-            options['max_depth'] = self.models_max_depth
-        if 'limit' not in options:
-            options['limit'] = self.models_limit
+        for option_name in ('max_depth', 'limit', 'allowed_lookups', 'disallowed_lookups'):
+            if option_name not in options:
+                options[option_name] = getattr(self, f'models_{option_name}')
         model_config = ModelConfig(orm_model=orm_model, schema=self, **options)
         self.models_configs.append(model_config)
         orm_model_manager_class = model_config.orm_model_manager.__class__
@@ -128,11 +136,21 @@ class Schema:
         """
             Execute a GraphQL query within the schema.
         """
-        print()
-        print()
-        print(query)
-        print()
-        print()
+        # debug logging
+        self._requests_logger.debug(json.dumps({
+            'authenticated_user': authenticated_user.username if authenticated_user is not None else None,
+            'query': query,
+            'operation_name': operation_name,
+            'variables': variables,
+        }))
+        # info logging
+        simpler_query = re.sub(r'#[^\n]+', '', query)
+        simpler_query = re.sub(r'\s+', ' ', simpler_query).strip()
+        self._requests_logger.info(json.dumps({
+            'authenticated_user': authenticated_user.username if authenticated_user is not None else None,
+            'query': simpler_query[:64] + '...' if len(simpler_query) > 64 else '',
+        }))
+        # actual query execution
         result = graphql_sync(
             schema = self._get_graphql_schema(),
             source = query,
@@ -142,6 +160,7 @@ class Schema:
                 authenticated_user = authenticated_user,
             ),
         )
+        # must the output be serializable?
         if serializable_output:
             formatted_result = result.formatted
             if 'errors' in formatted_result and not formatted_result['errors']:
@@ -346,10 +365,15 @@ class Schema:
                     kwargs[pass_graphql_path] = [type_, info.path.key]
                 # executed method
                 return method(**kwargs)
-            except exceptions.BaseError:
+            except exceptions.BaseError as error:
+                self._processing_logger.warning(error.args[0])
                 raise
             except Exception as error:
-                raise exceptions.InternalError(error if self.debug else None)
+                formatted_error = exceptions.InternalError(error)
+                self._processing_logger.warning(formatted_error.args[0])
+                if self.debug:
+                    raise formatted_error
+                raise exceptions.InternalError()
         return callback
 
     # using GraphQL core AST tree to return the GraphQL selection
